%
% Evaluation script for Rolling Shutter datasets
% For details, see the paper
% Forssen, Ringaby, "Rectifying Rolling Shutter Video from
% Hand-Held Devices", CVPR 2010
%
% (c) 2010 Erik Ringaby and Per-Erik Forssen

% Ground truth sequence
gt_seq='../house_rot1_B0/gt_mid/';
mask_seq='../house_rot1_B0/mask_mid/';
seq_name='ROT1 B0';

% Rectified sequence to evaluate
rect_seq='../house_rot1_B0/rolling_shutter/';
rect_name='Uncorrected';

% Frame interval to test
frame_range=1:12;

% Array for results
accuracy=zeros(size(frame_range));
% Threshold for accepting a pixel
acc_thres=0.3;

% Set this flag to display mask of accepted pixels
displayfl=0;

% Loop over frames in both sequences
for k=frame_range
    gt_k=im2double(imread([gt_seq sprintf('frame%02d.png',k)]));
    mask_k=im2double(imread([mask_seq sprintf('frame%02d.png',k)]));
    rect_k=im2double(imread([rect_seq sprintf('frame%02d.png',k)]));
    ok_k=findPassedPixels(rect_k,gt_k,mask_k,acc_thres);
    if displayfl,
        figure(1);clf
        subplot(2,2,1);image(gt_k);axis image
        subplot(2,2,2);image(repmat(mask_k,[1 1 3]));axis image
        subplot(2,2,3);image(rect_k);axis image
        subplot(2,2,4);image(repmat(ok_k,[1 1 3]));axis image
    end
    accuracy(k)=sum(ok_k(:))/sum(mask_k(:));
end

% Plot accuracy curve
figure(1);clf
plot(frame_range,accuracy,'.-');
axis([frame_range(1) frame_range(end) 0 1]);
grid on
title(['Accuracy for method "' rect_name '" on sequence "' seq_name '"']);
xlabel('Frame no')
ylabel('Fraction of accepted pixels')

fprintf('Average accuracy for method "%s" on sequence "%s" : %g\n',rect_name,seq_name,mean(accuracy));

